@@ -1,5 +1,3 @@
-#' @importFrom stats quantile
-#' @importFrom sjlabelled as_label get_labels
 #' @export
 print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
 
@@ -24,6 +22,10 @@ print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
   }
 
 
+  # remove std.error for printint
+  x$std.error <- NULL
+
+
   # do we have groups and facets?
   has_groups <- .obj_has_name(x, "group") && length(unique(x$group)) > 1
   has_facets <- .obj_has_name(x, "facet") && length(unique(x$facet)) > 1
@@ -31,13 +33,11 @@ print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
   has_response <- .obj_has_name(x, "response.level") && length(unique(x$response.level)) > 1
   has_se <- .obj_has_name(x, "std.error")
 
-  cat("\n")
-
   lab <- attr(x, "title", exact = TRUE)
   if (!is.null(lab)) insight::print_color(paste0(sprintf("# %s", lab), "\n", collapse = ""), "blue")
 
-  lab <- attr(x, "x.title", exact = TRUE)
-  if (!is.null(lab)) insight::print_color(paste0(sprintf("# x = %s", lab), "\n", collapse = ""), "blue")
+  # lab <- attr(x, "x.title", exact = TRUE)
+  # if (!is.null(lab)) insight::print_color(paste0(sprintf("# x = %s", lab), "\n", collapse = ""), "blue")
 
   consv <- attr(x, "constant.values")
   terms <- attr(x, "terms")
@@ -47,9 +47,13 @@ print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
   a1 <- attr(x, "fitfun", exact = TRUE)
   a2 <- attr(x, "y.title", exact = TRUE)
 
-  if (!is.null(a1) && !is.null(a2) && a1 == "coxph" && !(a2 == "Risk Score"))
+  if (!is.null(a1) && !is.null(a2) && a1 == "coxph" && !(a2 == "Risk Score") && !"time" %in% terms)
     terms <- c("time", terms)
 
+  # use focal term as column name
+  focal_term <- terms[1]
+  colnames(x)[1] <- focal_term
+
   x <- .round_numeric(x, digits = digits)
 
   # if we have groups, show n rows per group
@@ -194,7 +198,7 @@ print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
     cv.names <- names(cv)
     cv.space <- max(nchar(cv.names))
 
-    # ignore this string when determing maximum length
+    # ignore this string when determining maximum length
     poplev <- which(cv %in% c("NA (population-level)", "0 (population-level)"))
     if (!.is_empty(poplev))
       mcv <- cv[-poplev]
@@ -215,16 +219,14 @@ print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
   }
 
 
-  cat("\n")
-
   fitfun <- attr(x, "fitfun", exact = TRUE)
   if (has_se && !is.null(fitfun) && fitfun != "lm") {
-    message("Standard errors are on the link-scale (untransformed).")
+    message("\nStandard errors are on the link-scale (untransformed).")
   }
 
   predint <- attr(x, "prediction.interval", exact = TRUE)
   if (!is.null(predint) && isTRUE(predint)) {
-    message("Intervals are prediction intervals.")
+    message("\nIntervals are prediction intervals.")
   }
 }
 
@@ -248,7 +250,6 @@ print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
 
 
 
-#' @importFrom insight format_table format_ci
 .print_block <- function(i, n, digits, ci.lvl, ...) {
   i <- i[setdiff(colnames(i), c("group", "facet", "panel", "response.level", ".nest"))]
   # print.data.frame(, ..., row.names = FALSE, quote = FALSE)
@@ -270,6 +271,6 @@ print.ggeffects <- function(x, n = 10, digits = 2, x.lab = FALSE, ...) {
   }
 
   colnames(dd)[which(colnames(dd) == "predicted")] <- "Predicted"
-  cat(insight::format_table(dd, digits = digits, protect_integers = TRUE))
+  cat(insight::export_table(dd, digits = digits, protect_integers = TRUE))
   # print.data.frame(dd, ..., quote = FALSE, row.names = FALSE)
 }
