@@ -1,12 +1,18 @@
-#' @importFrom stats simulate quantile sd complete.cases
-simulate_predictions <- function(model, nsim, clean_terms, ci) {
+simulate_predictions <- function(model, nsim, clean_terms, ci, type) {
   fitfram <- insight::get_data(model)
   fam <- insight::model_info(model)
 
   if (fam$is_binomial || fam$is_multinomial || fam$is_ordinal || fam$is_categorical)
     stop("Can't simulate predictions from models with binary, categorical or ordinal outcome. Please use another option for argument `type`.", call. = FALSE)
 
-  sims <- stats::simulate(model, nsim = nsim, re.form = NULL)
+  if (type == "sim") {
+    sims <- suppressWarnings(tryCatch(
+      stats::simulate(model, nsim = nsim, re.form = NULL),
+      error = function(e) stats::simulate(model, nsim = nsim, re.form = NA)
+    ))
+  } else {
+    sims <- stats::simulate(model, nsim = nsim, re.form = NA)
+  }
 
   fitfram$predicted <- apply(sims, 1, mean)
   fitfram$conf.low <- apply(sims, 1, stats::quantile, probs = 1 - ci)
@@ -53,17 +59,31 @@ simulate_predictions <- function(model, nsim, clean_terms, ci) {
     std.error = unlist(lapply(means_se, function(i) if (is.null(i)) NA else i))
   )
   rownames(fitfram) <- NULL
-  fitfram <- fitfram[stats::complete.cases(fitfram), ]
+  fitfram <- fitfram[stats::complete.cases(fitfram), , drop = FALSE]
 
   if (length(clean_terms) == 1) {
-    fitfram <- fitfram[order(fitfram[[1]]), ]
+    fitfram <- fitfram[order(fitfram[[1]]), , drop = FALSE]
   } else if (length(clean_terms) == 2) {
-    fitfram <- fitfram[order(fitfram[[1]], fitfram[[2]]), ]
+    fitfram <- fitfram[order(fitfram[[1]], fitfram[[2]]), , drop = FALSE]
   } else if (length(clean_terms) == 3) {
-    fitfram <- fitfram[order(fitfram[[1]], fitfram[[2]], fitfram[[3]]), ]
+    fitfram <- fitfram[order(fitfram[[1]], fitfram[[2]], fitfram[[3]]), , drop = FALSE]
   } else if (length(clean_terms) == 4) {
-    fitfram <- fitfram[order(fitfram[[1]], fitfram[[2]], fitfram[[3]], fitfram[[4]]), ]
+    fitfram <- fitfram[order(fitfram[[1]], fitfram[[2]], fitfram[[3]], fitfram[[4]]), , drop = FALSE]
   }
 
   fitfram
 }
+
+
+
+.do_simulate <- function(model, terms, ci, type = "sim", ...) {
+  clean_terms <- .clean_terms(terms)
+  add.args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
+
+  if ("nsim" %in% names(add.args))
+    nsim <- eval(add.args[["nsim"]])
+  else
+    nsim <- 1000
+
+  simulate_predictions(model, nsim, clean_terms, ci, type)
+}
