@@ -147,16 +147,16 @@ data_frame <- function(...) {
 
 
 .get_residual_variance <- function(x) {
-  tryCatch(
+  out <- tryCatch(
     {
-      insight::get_sigma(x, verbose = FALSE)^2
+      insight::get_sigma(x, ci = NULL, verbose = FALSE)^2
       # info <- insight::model_info(x)
       # if (info$is_mixed || inherits(x, c("merMod", "rlmerMod", "lmerMod", "glmerMod", "glmmTMB", "stanreg", "MixMod"))) {
       #   re.var <- insight::get_variance_random(x)
       # } else if (inherits(x, c("lme", "nlme"))) {
       #   re.var <- x$sigma^2
       # } else {
-      #   re.var <- insight::get_sigma(x, verbose = FALSE)
+      #   re.var <- insight::get_sigma(x, ci = NULL, verbose = FALSE)
       #   if (is.null(re.var)) {
       #     re.var <- 0
       #   }
@@ -165,6 +165,12 @@ data_frame <- function(...) {
     },
     error = function(x) { 0 }
   )
+
+  if (!length(out)) {
+    return(0)
+  }
+
+  out
 }
 
 
